@@ -10,14 +10,15 @@ build_time_vars = {'ABIFLAGS': '',
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
  'ARFLAGS': 'rcs',
- 'BASECFLAGS': '-fno-strict-overflow',
+ 'BASECFLAGS': '-fno-strict-overflow -Wsign-compare',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/bin',
  'BINLIBDEST': '/usr/lib/python3.12',
  'BLDLIBRARY': '-L. -lpython3.12',
- 'BLDSHARED': 'gcc -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-              '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'BLDSHARED': 'gcc -shared -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
+              '-Wl,-z,relro -Wl,-z,now -Wl,-O1 -Wl,--sort-common '
+              '-Wl,--as-needed -Wl,-z,relro -Wl,-z,now',
  'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
@@ -26,14 +27,15 @@ build_time_vars = {'ABIFLAGS': '',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=armv8-a -O3 '
-           '-pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
-           '-Wformat -Werror=format-security         -fstack-clash-protection '
+ 'CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -g -O3 -Wall '
            '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
            '-Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         '
            '-fstack-clash-protection -march=armv8-a -O3 -pipe -fno-plt '
            '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
-           '-Werror=format-security         -fstack-clash-protection',
+           '-Werror=format-security         -fstack-clash-protection '
+           '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
+           '-Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         '
+           '-fstack-clash-protection',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -45,10 +47,14 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CFLAGS': '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
                      '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                      '-Werror=format-security         -fstack-clash-protection',
- 'CONFIGURE_CFLAGS_NODIST': '-std=c11 -Werror=implicit-function-declaration '
+ 'CONFIGURE_CFLAGS_NODIST': '-std=c11 -Wextra -Wno-unused-parameter '
+                            '-Wno-missing-field-initializers '
+                            '-Wstrict-prototypes '
+                            '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '',
- 'CONFIGURE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'CONFIGURE_LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+                      '-Wl,-z,now',
  'CONFIGURE_LDFLAGS_NODIST': '',
  'CONFIGURE_LDFLAGS_NOLTO': '',
  'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-computed-gotos' "
@@ -59,14 +65,14 @@ build_time_vars = {'ABIFLAGS': '',
                 '-O3 -pipe -fno-plt -fexceptions         '
                 '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                 "-Werror=format-security         -fstack-clash-protection' "
-                "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now' "
-                "'CPPFLAGS='",
+                "'LDFLAGS=-Wl,-O1 -Wl,--sort-common -Wl,--as-needed "
+                "-Wl,-z,relro -Wl,-z,now' 'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python/src/Python-3.12.4/coverage.info',
+ 'COVERAGE_INFO': '/build/python/src/Python-3.12.5/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/build/python/src/Python-3.12.4/lcov-report',
+ 'COVERAGE_REPORT': '/build/python/src/Python-3.12.5/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
@@ -625,20 +631,21 @@ build_time_vars = {'ABIFLAGS': '',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -shared',
- 'LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-            '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now '
+            '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now',
  'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.12.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-             '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'LDSHARED': 'gcc -shared -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
+             '-Wl,-z,relro -Wl,-z,now -Wl,-O1 -Wl,--sort-common '
+             '-Wl,--as-needed -Wl,-z,relro -Wl,-z,now',
  'LDVERSION': '3.12',
  'LIBC': '',
  'LIBDEST': '/usr/lib/python3.12',
  'LIBDIR': '/usr/lib',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
- 'LIBEXPAT_CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=armv8-a '
-                    '-O3 -pipe -fno-plt -fexceptions         '
+ 'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -g -O3 -Wall '
+                    '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
                     '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                     '-Werror=format-security         -fstack-clash-protection '
                     '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
@@ -647,14 +654,16 @@ build_time_vars = {'ABIFLAGS': '',
                     '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
                     '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                     '-Werror=format-security         -fstack-clash-protection '
-                    '-std=c11 -Werror=implicit-function-declaration '
+                    '-std=c11 -Wextra -Wno-unused-parameter '
+                    '-Wno-missing-field-initializers -Wstrict-prototypes '
+                    '-Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                     '-fPIC -fPIC',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
  'LIBHACL_CFLAGS': '-I./Modules/_hacl/include -D_BSD_SOURCE -D_DEFAULT_SOURCE '
-                   '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=armv8-a '
-                   '-O3 -pipe -fno-plt -fexceptions         '
+                   '-fno-strict-overflow -Wsign-compare -DNDEBUG -g -O3 -Wall '
+                   '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
                    '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
                    '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
@@ -663,9 +672,10 @@ build_time_vars = {'ABIFLAGS': '',
                    '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
                    '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-std=c11 -Werror=implicit-function-declaration '
-                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                   '-fPIC -fPIC',
+                   '-std=c11 -Wextra -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers -Wstrict-prototypes '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
+                   '-I./Include/internal -I. -I./Include -fPIC -fPIC',
  'LIBHACL_HEADERS': '\\',
  'LIBHACL_SHA2_A': 'Modules/_hacl/libHacl_Hash_SHA2.a',
  'LIBHACL_SHA2_HEADERS': '\\',
@@ -673,8 +683,8 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1 '
-                    '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=armv8-a '
-                    '-O3 -pipe -fno-plt -fexceptions         '
+                    '-fno-strict-overflow -Wsign-compare -DNDEBUG -g -O3 -Wall '
+                    '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
                     '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                     '-Werror=format-security         -fstack-clash-protection '
                     '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
@@ -683,7 +693,9 @@ build_time_vars = {'ABIFLAGS': '',
                     '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
                     '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                     '-Werror=format-security         -fstack-clash-protection '
-                    '-std=c11 -Werror=implicit-function-declaration '
+                    '-std=c11 -Wextra -Wno-unused-parameter '
+                    '-Wno-missing-field-initializers -Wstrict-prototypes '
+                    '-Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                     '-fPIC -fPIC',
  'LIBMPDEC_HEADERS': '\\',
@@ -1048,8 +1060,8 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha2,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall '
-                             '-march=armv8-a -O3 -pipe -fno-plt '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -g '
+                             '-O3 -Wall -march=armv8-a -O3 -pipe -fno-plt '
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
                              '-Wformat -Werror=format-security         '
                              '-fstack-clash-protection -march=armv8-a -O3 '
@@ -1060,24 +1072,30 @@ build_time_vars = {'ABIFLAGS': '',
                              '-pipe -fno-plt -fexceptions         '
                              '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                              '-Werror=format-security         '
-                             '-fstack-clash-protection -std=c11 '
+                             '-fstack-clash-protection -std=c11 -Wextra '
+                             '-Wno-unused-parameter '
+                             '-Wno-missing-field-initializers '
+                             '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
                              '-I./Include -fPIC -DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=armv8-a -O3 '
-              '-pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
-              '-Wformat -Werror=format-security         '
-              '-fstack-clash-protection -march=armv8-a -O3 -pipe -fno-plt '
-              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
+ 'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -g -O3 -Wall '
+              '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
+              '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
+              '-Werror=format-security         -fstack-clash-protection '
+              '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
+              '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
               '-Werror=format-security         -fstack-clash-protection '
               '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
               '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
               '-Werror=format-security         -fstack-clash-protection',
- 'PY_CFLAGS_NODIST': '-std=c11 -Werror=implicit-function-declaration '
+ 'PY_CFLAGS_NODIST': '-std=c11 -Wextra -Wno-unused-parameter '
+                     '-Wno-missing-field-initializers -Wstrict-prototypes '
+                     '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=armv8-a '
-                   '-O3 -pipe -fno-plt -fexceptions         '
+ 'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -g -O3 -Wall '
+                   '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
                    '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
                    '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
@@ -1086,25 +1104,29 @@ build_time_vars = {'ABIFLAGS': '',
                    '-march=armv8-a -O3 -pipe -fno-plt -fexceptions         '
                    '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-std=c11 -Werror=implicit-function-declaration '
-                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                   '-fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-                    '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+                   '-std=c11 -Wextra -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers -Wstrict-prototypes '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
+                   '-I./Include/internal -I. -I./Include -fPIC -DPy_BUILD_CORE',
+ 'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+                    '-Wl,-z,now -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
+                    '-Wl,-z,relro -Wl,-z,now',
  'PY_CPPFLAGS': '-I. -I./Include',
  'PY_ENABLE_SHARED': 1,
  'PY_HAVE_PERF_TRAMPOLINE': 1,
- 'PY_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-               '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'PY_LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+               '-Wl,-z,now -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
+               '-Wl,-z,relro -Wl,-z,now',
  'PY_LDFLAGS_NODIST': '',
- 'PY_LDFLAGS_NOLTO': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-                     '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'PY_LDFLAGS_NOLTO': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+                     '-Wl,-z,now -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
+                     '-Wl,-z,relro -Wl,-z,now',
  'PY_SQLITE_ENABLE_LOAD_EXTENSION': 1,
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall '
-                        '-march=armv8-a -O3 -pipe -fno-plt '
+ 'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -g -O3 '
+                        '-Wall -march=armv8-a -O3 -pipe -fno-plt '
                         '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                         '-Werror=format-security         '
                         '-fstack-clash-protection -march=armv8-a -O3 -pipe '
@@ -1113,7 +1135,9 @@ build_time_vars = {'ABIFLAGS': '',
                         '-fstack-clash-protection -march=armv8-a -O3 -pipe '
                         '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
                         '-Wformat -Werror=format-security         '
-                        '-fstack-clash-protection -std=c11 '
+                        '-fstack-clash-protection -std=c11 -Wextra '
+                        '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
                         '-I./Include -fPIC',
@@ -1128,7 +1152,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.4',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.5',
  'SCRIPTDIR': '/usr/lib',
  'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
  'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
@@ -1254,9 +1278,9 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.4 ./python -E',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.5 ./python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.4 ./python -E '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.5 ./python -E '
                './Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
@@ -1286,8 +1310,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python/src/Python-3.12.4',
- 'abs_srcdir': '/build/python/src/Python-3.12.4',
+ 'abs_builddir': '/build/python/src/Python-3.12.5',
+ 'abs_srcdir': '/build/python/src/Python-3.12.5',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
